@@ -48,14 +48,11 @@ exchange_summary_check_for_trash (CamelFolder *folder)
 {
 	CamelStore *parent_store;
 	CamelFolder *trash;
-	CamelException lex;
-
-	camel_exception_init (&lex);
 
 	parent_store = camel_folder_get_parent_store (folder);
-	trash = camel_store_get_trash (parent_store, &lex);
+	trash = camel_store_get_trash (parent_store, NULL);
 
-	if (camel_exception_is_set (&lex) || !trash)
+	if (trash == NULL)
 		return FALSE;
 
 	return folder == trash;
@@ -63,27 +60,26 @@ exchange_summary_check_for_trash (CamelFolder *folder)
 
 static gboolean
 exchange_summary_expunge_mail (CamelFolder *folder,
-                               CamelMessageInfo *info)
+                               CamelMessageInfo *info,
+                               GError **error)
 {
 	GPtrArray *uids = g_ptr_array_new ();
 	CamelStore *parent_store;
 	gchar *uid = g_strdup (info->uid);
-	CamelException lex;
 	const gchar *full_name;
-
-	camel_exception_init (&lex);
+	gboolean success;
 
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
 	g_ptr_array_add (uids, uid);
 
-	camel_exchange_utils_expunge_uids (
-		CAMEL_SERVICE (parent_store), full_name, uids, &lex);
+	success = camel_exchange_utils_expunge_uids (
+		CAMEL_SERVICE (parent_store), full_name, uids, error);
 
 	g_ptr_array_free (uids, TRUE);
 
-	return camel_exception_is_set (&lex);
+	return success;
 }
 
 static gint
@@ -154,8 +150,8 @@ exchange_summary_header_save (CamelFolderSummary *summary,
 }
 
 static CamelMessageInfo *
-exchange_summary_message_info_load (CamelFolderSummary *summary,
-                                    FILE *in)
+exchange_summary_message_info_migrate (CamelFolderSummary *summary,
+                                       FILE *in)
 {
 	CamelMessageInfo *info;
 	CamelExchangeMessageInfo *einfo;
@@ -165,7 +161,7 @@ exchange_summary_message_info_load (CamelFolderSummary *summary,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	info = folder_summary_class->message_info_load (summary, in);
+	info = folder_summary_class->message_info_migrate (summary, in);
 	if (info) {
 		einfo = (CamelExchangeMessageInfo *)info;
 
@@ -195,31 +191,6 @@ error:
 	return NULL;
 }
 
-static gint
-exchange_summary_message_info_save (CamelFolderSummary *summary,
-                                    FILE *out,
-                                    CamelMessageInfo *info)
-{
-	CamelExchangeMessageInfo *einfo = (CamelExchangeMessageInfo *)info;
-	CamelFolderSummaryClass *folder_summary_class;
-
-	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
-		camel_exchange_summary_parent_class);
-
-	if (folder_summary_class->message_info_save (summary, out, info) == -1)
-		return -1;
-
-	if (camel_file_util_encode_string (out, einfo->thread_index ? einfo->thread_index : "") == -1)
-		return -1;
-
-	if (camel_file_util_encode_string (out, einfo->href ? einfo->href : "") == -1)
-		return -1;
-
-	d(g_print ("%s:%s: einfo->href = [%s]\n", G_STRLOC, G_STRFUNC, einfo->href));
-
-	return 0;
-}
-
 static CamelMessageInfo *
 exchange_summary_message_info_new_from_header (CamelFolderSummary *summary,
                                                struct _camel_header_raw *h)
@@ -267,7 +238,7 @@ exchange_summary_message_info_free (CamelFolderSummary *summary,
 
 static CamelFIRecord *
 exchange_summary_summary_header_to_db (CamelFolderSummary *s,
-                                       CamelException *ex)
+                                       GError **error)
 {
 	CamelExchangeSummary *exchange = (CamelExchangeSummary *) s;
 	CamelFolderSummaryClass *folder_summary_class;
@@ -276,7 +247,7 @@ exchange_summary_summary_header_to_db (CamelFolderSummary *s,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	fir = folder_summary_class->summary_header_to_db (s, ex);
+	fir = folder_summary_class->summary_header_to_db (s, error);
 	if (!fir)
 		return NULL;
 	fir->bdata = g_strdup_printf ("%u %u %u", exchange->version, exchange->readonly, exchange->high_article_num);
@@ -346,7 +317,7 @@ exchange_summary_message_info_from_db (CamelFolderSummary *s,
 
 	info = folder_summary_class->message_info_from_db (s, mir);
 	if (info) {
-		gchar *part = g_strdup (mir->bdata);
+		gchar *part = mir->bdata;
 		gint len;
 		einfo = (CamelExchangeMessageInfo *)info;
 		EXTRACT_FIRST_STRING (einfo->thread_index)
@@ -383,7 +354,7 @@ exchange_summary_info_set_flags (CamelMessageInfo *info,
 		if (folder && info->uid) {
 			if ((flags & set & CAMEL_MESSAGE_DELETED) &&
 			    exchange_summary_check_for_trash (folder)) {
-				return exchange_summary_expunge_mail (folder, info);
+				return exchange_summary_expunge_mail (folder, info, NULL);
 			} else {
 				camel_exchange_utils_set_message_flags (
 					CAMEL_SERVICE (parent_store),
@@ -450,8 +421,7 @@ camel_exchange_summary_class_init (CamelExchangeSummaryClass *class)
 	folder_summary_class->content_info_size = sizeof (CamelMessageContentInfo);
 	folder_summary_class->summary_header_load = exchange_summary_header_load;
 	folder_summary_class->summary_header_save = exchange_summary_header_save;
-	folder_summary_class->message_info_load = exchange_summary_message_info_load;
-	folder_summary_class->message_info_save = exchange_summary_message_info_save;
+	folder_summary_class->message_info_migrate = exchange_summary_message_info_migrate;
 	folder_summary_class->message_info_new_from_header = exchange_summary_message_info_new_from_header;
 	folder_summary_class->message_info_free = exchange_summary_message_info_free;
 	folder_summary_class->summary_header_to_db = exchange_summary_summary_header_to_db;
@@ -479,22 +449,21 @@ CamelFolderSummary *
 camel_exchange_summary_new (struct _CamelFolder *folder, const gchar *filename)
 {
 	CamelFolderSummary *summary;
-	CamelException lex;
+	GError *local_error = NULL;
 
-	camel_exception_init (&lex);
 	summary = g_object_new (CAMEL_TYPE_EXCHANGE_SUMMARY, NULL);
 	summary->folder = folder;
 	camel_folder_summary_set_filename (summary, filename);
-	if (camel_folder_summary_load_from_db (summary, &lex) == -1) {
+	if (camel_folder_summary_load_from_db (summary, &local_error) == -1) {
 		g_warning (
 			"Unable to load Exchage summary for folder %s: %s\n",
 			camel_folder_get_full_name (folder),
-			camel_exception_get_description(&lex));
+			local_error->message);
 		camel_folder_summary_clear_db (summary);
 		camel_folder_summary_touch (summary);
+		g_error_free (local_error);
 	}
 
-	camel_exception_clear (&lex);
 	return summary;
 }
 
